#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gi-gobject
version:                2.0.31
visibility:             public
id:                     gi-gobject-2.0.31-8VAXehTXZXxDdBwzUXltf5
key:                    gi-gobject-2.0.31-8VAXehTXZXxDdBwzUXltf5
license:                LGPL-2.1-only
maintainer:             Iñaki García Etxebarria
author:                 Iñaki García Etxebarria
homepage:               https://github.com/haskell-gi/haskell-gi
synopsis:               GObject bindings
description:            Bindings for GObject, autogenerated by haskell-gi.
category:               Bindings
abi:                    18d6b16ba815d9ebd28a8fbbaf22219b
exposed:                True
exposed-modules:
    GI.GObject GI.GObject.Callbacks GI.GObject.Config
    GI.GObject.Constants GI.GObject.Flags GI.GObject.Functions
    GI.GObject.Interfaces GI.GObject.Interfaces.TypePlugin
    GI.GObject.Objects GI.GObject.Objects.Binding
    GI.GObject.Objects.BindingGroup GI.GObject.Objects.InitiallyUnowned
    GI.GObject.Objects.Object GI.GObject.Objects.ParamSpec
    GI.GObject.Objects.ParamSpecBoolean
    GI.GObject.Objects.ParamSpecBoxed GI.GObject.Objects.ParamSpecChar
    GI.GObject.Objects.ParamSpecDouble GI.GObject.Objects.ParamSpecEnum
    GI.GObject.Objects.ParamSpecFlags GI.GObject.Objects.ParamSpecFloat
    GI.GObject.Objects.ParamSpecGType GI.GObject.Objects.ParamSpecInt
    GI.GObject.Objects.ParamSpecInt64 GI.GObject.Objects.ParamSpecLong
    GI.GObject.Objects.ParamSpecObject
    GI.GObject.Objects.ParamSpecOverride
    GI.GObject.Objects.ParamSpecParam
    GI.GObject.Objects.ParamSpecPointer
    GI.GObject.Objects.ParamSpecString
    GI.GObject.Objects.ParamSpecUChar GI.GObject.Objects.ParamSpecUInt
    GI.GObject.Objects.ParamSpecUInt64
    GI.GObject.Objects.ParamSpecULong
    GI.GObject.Objects.ParamSpecUnichar
    GI.GObject.Objects.ParamSpecValueArray
    GI.GObject.Objects.ParamSpecVariant GI.GObject.Objects.SignalGroup
    GI.GObject.Objects.TypeModule GI.GObject.Structs
    GI.GObject.Structs.CClosure GI.GObject.Structs.ClosureNotifyData
    GI.GObject.Structs.EnumClass GI.GObject.Structs.EnumValue
    GI.GObject.Structs.FlagsClass GI.GObject.Structs.FlagsValue
    GI.GObject.Structs.InitiallyUnownedClass
    GI.GObject.Structs.InterfaceInfo GI.GObject.Structs.ObjectClass
    GI.GObject.Structs.ObjectConstructParam
    GI.GObject.Structs.ParamSpecPool
    GI.GObject.Structs.ParamSpecTypeInfo GI.GObject.Structs.Parameter
    GI.GObject.Structs.SignalInvocationHint
    GI.GObject.Structs.SignalQuery GI.GObject.Structs.TypeClass
    GI.GObject.Structs.TypeFundamentalInfo GI.GObject.Structs.TypeInfo
    GI.GObject.Structs.TypeInstance GI.GObject.Structs.TypeInterface
    GI.GObject.Structs.TypeQuery GI.GObject.Structs.TypeValueTable
    GI.GObject.Structs.ValueArray GI.GObject.Structs.WeakRef
    GI.GObject.Unions GI.GObject.Unions.TypeCValue
    GI.GObject.Unions.Value_Data_Union_

import-dirs:            /usr/lib/ghc-9.6.6/site-local/gi-gobject-2.0.31
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/gi-gobject-2.0.31 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/gi-gobject-2.0.31 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gi-gobject
hs-libraries:           HSgi-gobject-2.0.31-8VAXehTXZXxDdBwzUXltf5
extra-libraries:        gobject-2.0 glib-2.0
extra-libraries-static:
    gobject-2.0 glib-2.0 atomic m sysprof-capture-4 pcre2-8 pthread ffi

include-dirs:
    /usr/include /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/sysprof-6

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    gi-glib-2.0.30-50qvdYSAZw5ED4OPu6p9eN
    haskell-gi-0.26.17-ETu2VhCOBw82h6qCA3NIIR
    haskell-gi-base-0.26.9-A51M6LjdiVN4RjdHJdLeji
    haskell-gi-overloading-1.0-6w3IXGDooXgu3RA2LfTuf text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:     /usr/share/doc/haskell-gi-gobject/html/gi-gobject.haddock
haddock-html:           /usr/share/doc/haskell-gi-gobject/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

